==> ejc-middlemeasurement-impl-3.0.0-20220929.033104-135-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractingvolumemdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包报量报告物资扣款子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractingvolumemdetail")
public class SubcontractingvolumemdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编码
    @TableField(value="bill_name")
    private java.lang.String billName; // 物资名称
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="m_unitprice")
    private java.math.BigDecimal mUnitprice; // 单价(元)
    @TableField(value="budgetquantity")
    private java.math.BigDecimal budgetquantity; // 预算数量
    @TableField(value="actual_consumption")
    private java.math.BigDecimal actualConsumption; // 实际消耗数量
    @TableField(value="excessdosage")
    private java.math.BigDecimal excessdosage; // 超用量
    @TableField(value="overdraft_deduction")
    private java.math.BigDecimal overdraftDeduction; // 超用扣款
    @TableField(value="withholding")
    private java.lang.String withholding; // 代扣款
    @TableField(value="section")
    private String section; // 区段
    @TableField(value="subitem_desc")
    private String subitemDesc; // 子目特征描述


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getBillName() {
        return billName;
    }

    /**
     * 物资名称
     */
    public void setBillName(java.lang.String billName) {
        this.billName = billName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getmUnitprice() {
        return mUnitprice;
    }

    public void setmUnitprice(BigDecimal mUnitprice) {
        this.mUnitprice = mUnitprice;
    }

    /**
     * 预算数量
     */
    public java.math.BigDecimal getBudgetquantity() {
        return budgetquantity;
    }

    /**
     * 预算数量
     */
    public void setBudgetquantity(java.math.BigDecimal budgetquantity) {
        this.budgetquantity = budgetquantity;
    }
    /**
     * 实际消耗数量
     */
    public java.math.BigDecimal getActualConsumption() {
        return actualConsumption;
    }

    /**
     * 实际消耗数量
     */
    public void setActualConsumption(java.math.BigDecimal actualConsumption) {
        this.actualConsumption = actualConsumption;
    }
    /**
     * 超用量
     */
    public java.math.BigDecimal getExcessdosage() {
        return excessdosage;
    }

    /**
     * 超用量
     */
    public void setExcessdosage(java.math.BigDecimal excessdosage) {
        this.excessdosage = excessdosage;
    }
    /**
     * 超用扣款
     */
    public java.math.BigDecimal getOverdraftDeduction() {
        return overdraftDeduction;
    }

    /**
     * 超用扣款
     */
    public void setOverdraftDeduction(java.math.BigDecimal overdraftDeduction) {
        this.overdraftDeduction = overdraftDeduction;
    }
    /**
     * 代扣款
     */
    public java.lang.String getWithholding() {
        return withholding;
    }

    /**
     * 代扣款
     */
    public void setWithholding(java.lang.String withholding) {
        this.withholding = withholding;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221024.101540-187-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractingvolumemdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包报量报告物资扣款子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_subcontractingvolumemdetail")
public class SubcontractingvolumemdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="bill_code")
    private java.lang.String billCode; // 编码
    @TableField(value="bill_name")
    private java.lang.String billName; // 物资名称
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="m_unitprice")
    private java.math.BigDecimal mUnitprice; // 单价(元)
    @TableField(value="budgetquantity")
    private java.math.BigDecimal budgetquantity; // 预算数量
    @TableField(value="actual_consumption")
    private java.math.BigDecimal actualConsumption; // 实际消耗数量
    @TableField(value="excessdosage")
    private java.math.BigDecimal excessdosage; // 超用量
    @TableField(value="overdraft_deduction")
    private java.math.BigDecimal overdraftDeduction; // 超用扣款
    @TableField(value="withholding")
    private BigDecimal withholding; // 代扣款
    @TableField(value="section")
    private String section; // 区段
    @TableField(value="subitem_desc")
    private String subitemDesc; // 子目特征描述
    @TableField(value="remark")
    private String remark; // 备注


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getBillName() {
        return billName;
    }

    /**
     * 物资名称
     */
    public void setBillName(java.lang.String billName) {
        this.billName = billName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getmUnitprice() {
        return mUnitprice;
    }

    public void setmUnitprice(BigDecimal mUnitprice) {
        this.mUnitprice = mUnitprice;
    }

    /**
     * 预算数量
     */
    public java.math.BigDecimal getBudgetquantity() {
        return budgetquantity;
    }

    /**
     * 预算数量
     */
    public void setBudgetquantity(java.math.BigDecimal budgetquantity) {
        this.budgetquantity = budgetquantity;
    }
    /**
     * 实际消耗数量
     */
    public java.math.BigDecimal getActualConsumption() {
        return actualConsumption;
    }

    /**
     * 实际消耗数量
     */
    public void setActualConsumption(java.math.BigDecimal actualConsumption) {
        this.actualConsumption = actualConsumption;
    }
    /**
     * 超用量
     */
    public java.math.BigDecimal getExcessdosage() {
        return excessdosage;
    }

    /**
     * 超用量
     */
    public void setExcessdosage(java.math.BigDecimal excessdosage) {
        this.excessdosage = excessdosage;
    }
    /**
     * 超用扣款
     */
    public java.math.BigDecimal getOverdraftDeduction() {
        return overdraftDeduction;
    }

    /**
     * 超用扣款
     */
    public void setOverdraftDeduction(java.math.BigDecimal overdraftDeduction) {
        this.overdraftDeduction = overdraftDeduction;
    }

    public BigDecimal getWithholding() {
        return withholding;
    }

    public void setWithholding(BigDecimal withholding) {
        this.withholding = withholding;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    /**
     * 代扣款
     */


    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }
}
